@@ -42,4 +42,7 @@ def run(runner, debug=False, text=False):
 
 def execute(obj, args):
     method = getattr(obj, args.action)
-    run(lambda: call(method, vars(args)), args.debug, args.text)
+    text = False
+    if hasattr(args, 'text'):
+        text = args.text
+    run(lambda: call(method, vars(args)), args.debug, text)
